@@ -27,7 +27,7 @@ pub fn register_all_ops(reg: &mut OnnxOpRegister) {
     reg.insert("GatherND", gather_nd);
     reg.insert("NonZero", |_, _| Ok((Box::new(nonzero::NonZero::non_zero()), vec![])));
     reg.insert("OneHot", one_hot::one_hot);
-    reg.insert("Range", |_, _| Ok((Box::new(array::Range::default()), vec![])));
+    reg.insert("Range", |_, _| Ok((expand(array::Range::default()), vec![])));
     reg.insert("Pad", pad::pad);
     reg.insert("Reshape", |_, _| Ok((expand(array::Reshape::default()), vec![])));
     reg.insert("Scatter", scatter_elements);
